@@ -109,6 +109,15 @@ module BloggerPost
       res
     end
 
+    # to avoid REXML bug at Ruby 1.8.6
+    def find_element_with_attr(doc, path, key, value)
+      finded = nil
+      doc.elements.each(path) do |element|
+        finded = element if element.attributes[key] == value
+      end
+      finded
+    end
+
     def parse_atom(src)
       doc = REXML::Document.new(src)
       published_element = doc.elements['/entry/published']
@@ -117,14 +126,18 @@ module BloggerPost
       updated_element = doc.elements['/entry/updated']
       updated_element = doc.elements['/entry/modified'] unless updated_element
       updated_element = published_element unless updated_element
-      edit_id_element = doc.elements["/entry/link[@rel='service.edit']"]
-      edit_id_element = doc.elements["/entry/link[@rel='edit']"] unless edit_id_element
+      # edit_id_element = doc.elements["/entry/link[@rel='service.edit']"]
+      edit_id_element = find_element_with_attr(doc, '/entry/link', 'rel', 'service.edit')
+      # edit_id_element = doc.elements["/entry/link[@rel='edit']"] unless edit_id_element
+      edit_id_element = find_element_with_attr(doc, '/entry/link', 'rel', 'edit') unless edit_id_element
       if edit_id_element
         edit_id = edit_id_element.attributes['href']
       else
         edit_id = nil
       end
-      [published_element.text, updated_element.text, doc.elements["/entry/link[@rel='alternate']"].attributes['href'], edit_id]
+      # href = doc.elements["/entry/link[@rel='alternate']"].attributes['href']
+      href = find_element_with_attr(doc, '/entry/link', 'rel', 'alternate').attributes['href']
+      [published_element.text, updated_element.text, href, edit_id]
     end
 
     def response_atom_to_entry(entry, method, response_body)
@@ -198,9 +211,11 @@ module BloggerPost
       raise "Couldn't edit url." unless res.code == '200'
       doc = REXML::Document.new(res.body)
       doc.elements.each('/feed/entry') do |entry_element|
-        url = entry_element.elements["link[@rel='alternate']"].attributes['href']
+        # url = entry_element.elements["link[@rel='alternate']"].attributes['href']
+        url = find_element_with_attr(entry_element, 'link', 'rel', 'alternate').attributes['href']
         if entry.url == url
-          edit_link = entry_element.elements["link[@rel='service.edit']"]
+          # edit_link = entry_element.elements["link[@rel='service.edit']"]
+          edit_link = find_element_with_attr(entry_element, 'link', 'rel', 'alternate').attributes['href']
           entry.edit_id =  edit_link.attributes['href'] if edit_link
           return
         end
