@@ -1,8 +1,6 @@
 require 'bloggerpost'
 require 'jcode'
 
-$KCODE='e'
-
 def STDIN.eof?
   false
 end
@@ -14,6 +12,8 @@ module BloggerPost
   end
 
   class ::BloggerPost::Folder
+    include ::BloggerPost::Common
+    
     attr_reader :entry_list, :name, :title, :search_list
 
     def initialize(entry_list, name, title, is_draft)
@@ -40,15 +40,15 @@ module BloggerPost
         regexp = /#{Regexp.escape(search['word'])}/m
         case search['type']
         when 'Title'
-          return false unless entry.title =~ regexp
+          return false unless to_external_encode(entry.title) =~ regexp
         when 'Body'
           return false unless entry.body =~ regexp
         when 'Tag'
-          return false unless entry.tag_list.find {|tag| tag =~ regexp }
+          return false unless entry.tag_list.find {|tag| to_external_encode(tag) =~ regexp }
         when 'Category'
-          return false unless entry.category_list.find {|category| category =~ regexp }
+          return false unless entry.category_list.find {|category| to_external_encode(category) =~ regexp }
         when 'Trackback'
-          return false unless entry.trackback_list.find {|trackback| trackback =~ regexp }
+          return false unless entry.trackback_list.find {|trackback| to_external_encode(trackback) =~ regexp }
         end
       end
       true
@@ -62,7 +62,7 @@ module BloggerPost
     def initialize(config)
       @config = config
       @name = 'draft'
-      @title = ''
+      @title = '下書き'
     end
 
     def delete_entry(entry)
@@ -72,8 +72,10 @@ module BloggerPost
   end
   
   class ElBPApp < ElApp
-    WEEK_DAY = ['', '', '', '', '', '', '']
-    DATE_FORMAT = '%Yǯ%m%d'
+    include ::BloggerPost::Common
+
+    WEEK_DAY = ['日', '月', '火', '水', '木', '金', '土']
+    DATE_FORMAT = '%Y年%m月%d日'
     TIME_FORMAT = '%H:%M'
     BODY_SEPARATOR = '--text follows this line--'
 
@@ -210,7 +212,6 @@ module BloggerPost
       @current_folder = ::BloggerPost::Folder.new(entry_list, '', '', false)
       entrylist_read_search_word
       bloggerpost_entrylist
-      bloggerpost_entrylist_update
     end
 
     # blog list
@@ -238,7 +239,6 @@ module BloggerPost
       end
       @current_folder = ::BloggerPost::Folder.new(entry_list, name, title, is_draft)
       bloggerpost_entrylist
-      bloggerpost_entrylist_update
     end
 
     defun(:bloggerpost_bloglist_exit, :interactive => true) do
@@ -251,18 +251,18 @@ module BloggerPost
         let(:buffer_read_only, false) do
           erase_buffer
           blog_name_width = @blog_list.collect {|blog| blog.blog_name.length }.push(@draft.name.length).max
-          title_width = @blog_list.collect {|blog| blog.title.toeuc.length }.max
+          title_width = @blog_list.collect {|blog| to_external_encode(blog.title).length }.max
           count_width = @blog_list.collect {|blog| blog.entry_list.length.to_s.length }.push(@draft.entry_list.length.to_s.length).max
           draft_line = " [ #{@draft.name}#{' ' * (blog_name_width - @draft.name.length)} ] "
           num = @draft.entry_list.length
           draft_line << "(#{num.to_s})#{' ' * (count_width - num.to_s.length + 1)}"
-          draft_line << @draft.title
+          draft_line << to_external_encode(@draft.title)
           insert_with_properties(cut_string(draft_line, window_width - 1), [:draft, true, :face, :bloggerpost_blog_face])
           newline
           @blog_list.each do |blog|
             blog_line = ' [ ' + blog.blog_name + ' ' * (blog_name_width - blog.blog_name.length) + ' ] '
             blog_line << '(' + blog.entry_list.length.to_s + ')' + ' ' * (count_width - blog.entry_list.length.to_s.length + 1)
-            blog_line << blog.title.toeuc + ' ' * (title_width - blog.title.toeuc.length + 1)
+            blog_line << to_external_encode(blog.title) + ' ' * (title_width - to_external_encode(blog.title).length + 1)
             blog_line << blog.url
             insert_with_properties(cut_string(blog_line, window_width - 1), [:blog_name, blog.blog_name, :face, :bloggerpost_blog_face])
             newline
@@ -443,8 +443,8 @@ module BloggerPost
           n = 1
           @current_folder.entry_list.each do |entry|
             entry_line = ' ' + "%#{@current_folder.entry_list.length.to_s.length}d" % n + ' '
-            entry_line << format_date(entry.date) + ' '
-            entry_line << entry.title.toeuc
+            entry_line << to_external_encode(format_date(entry.date)) + ' '
+            entry_line << to_external_encode(entry.title)
             face = nil
             case entry.status
             when ::BloggerPost::STATUS_DELETED
@@ -463,7 +463,7 @@ module BloggerPost
       end
       goto_line(point_max)
       forward_line(-1)
-      elvar.mode_line_buffer_identification = @current_folder.title.toeuc + " [#{@current_folder.name}]"
+      elvar.mode_line_buffer_identification = to_external_encode(@current_folder.title) + " [#{@current_folder.name}]"
       force_mode_line_update
     end
 
@@ -579,7 +579,6 @@ module BloggerPost
     defun(:bloggerpost_entry_exit, :interactive => true) do
       delete_other_windows
       bloggerpost_entrylist
-      bloggerpost_entrylist_update
     end
 
     def insert_entry_header(header, content, content_face = :bloggerpost_entry_header_contents_face)
@@ -594,18 +593,18 @@ module BloggerPost
         let(:buffer_read_only, false) do
           erase_buffer
           prev_point = point
-          insert_entry_header('Title: ', entry.title.toeuc, :bloggerpost_entry_title_face)
-          insert_entry_header('Date: ', format_date(entry.date), :bloggerpost_entry_date_face)
+          insert_entry_header('Title: ', to_external_encode(entry.title), :bloggerpost_entry_title_face)
+          insert_entry_header('Date: ', to_external_encode(format_date(entry.date)), :bloggerpost_entry_date_face)
           insert_entry_header('URL: ', entry.url) unless entry.draft?
           insert_entry_header('Style: ', entry.style.style_name)
-          insert_entry_header('Tag: ', entry.tag_list.collect {|tag| tag.toeuc }.join(', ')) unless entry.tag_list.empty?
-          insert_entry_header('Category: ', entry.category_list.collect {|category| category.toeuc }.join(', ')) unless entry.category_list.empty?
+          insert_entry_header('Tag: ', entry.tag_list.collect {|tag| to_external_encode(tag) }.join(', ')) unless entry.tag_list.empty?
+          insert_entry_header('Category: ', entry.category_list.collect {|category| to_external_encode(category) }.join(', ')) unless entry.category_list.empty?
           insert_entry_header('Trackback: ', entry.trackback_list.collect.join(', ')) unless entry.trackback_list.empty?
           newline
-          insert(entry.body.toeuc)
+          insert(entry.body)
         end
       end
-      elvar.mode_line_buffer_identification = entry.title.toeuc + " [#{entry.blog.blog_name}]"
+      elvar.mode_line_buffer_identification = to_external_encode(entry.title) + " [#{entry.blog.blog_name}]"
       force_mode_line_update
     end
 
@@ -666,14 +665,14 @@ module BloggerPost
         if entry.status == entry.draft?
           insert_draft_header('Blog: ', entry.blog.blog_name)
         end
-        insert_draft_header('Title: ', entry.title.toeuc)
-        insert_draft_header('Tag: ', entry.tag_list.collect {|tag| tag.toeuc }.join(', '))
-        insert_draft_header('Category: ', entry.category_list.collect {|category| category.toeuc }.join(', '))
+        insert_draft_header('Title: ', to_external_encode(entry.title))
+        insert_draft_header('Tag: ', entry.tag_list.collect {|tag| to_external_encode(tag) }.join(', '))
+        insert_draft_header('Category: ', entry.category_list.collect {|category| to_external_encode(category) }.join(', '))
         if entry.status == entry.draft?
           insert_draft_header('Trackback: ', entry.trackback_list.collect.join(', '))
         end
         insert_draft_separator
-        insert(entry.body.toeuc)
+        insert(entry.body)
         beginning_of_buffer
         search_forward("Title: ", nil, true)
       end
@@ -723,12 +722,12 @@ module BloggerPost
 
     def get_header(entry_string, header)
       entry_string =~ /^#{header}: (.*)$/
-      $1.strip.toutf8
+      to_internal_encode($1.strip)
     end
 
     def get_header_array(entry_string, header)
       entry_string =~ /^#{header}: (.*)$/
-      $1.split(',').collect {|content| content.strip.toutf8 }
+      $1.split(',').collect {|content| to_internal_encode(content.strip) }
     end
 
     def read_buffer_to_entry
